Commit 5afce06b authored by Derk-Jan Hartman's avatar Derk-Jan Hartman

* ffmpeg resample.c patch is no longer necessary

* new liveMedia version
* liveMedia mp3 tabsel nameconflict patch no longer needed. (Accepted upstream).
parent 46bcf2ee
......@@ -35,18 +35,6 @@ diff -ru ffmpeg.old/libavcodec/libpostproc/Makefile ffmpeg/libavcodec/libpostpro
endif
diff -ru ffmpeg.old/libavcodec/resample.c ffmpeg/libavcodec/resample.c
--- ffmpeg.old/libavcodec/resample.c Mon Sep 8 23:05:43 2003
+++ ffmpeg/libavcodec/resample.c Sun Nov 2 02:04:09 2003
@@ -49,7 +49,7 @@
static void init_mono_resample(ReSampleChannelContext *s, float ratio)
{
ratio = 1.0 / ratio;
- s->iratio = (int)floorf(ratio);
+ s->iratio = (int)floor(ratio);
if (s->iratio == 0)
s->iratio = 1;
s->incr = (int)((ratio / s->iratio) * FRAC);
diff -ru ffmpeg.old/libavformat/rtsp.c ffmpeg/libavformat/rtsp.c
--- ffmpeg.old/libavformat/rtsp.c Wed Oct 29 15:25:27 2003
+++ ffmpeg/libavformat/rtsp.c Sun Nov 2 02:04:09 2003
......
......@@ -22,47 +22,3 @@ diff -ru live/groupsock/NetInterface.cpp live-patched/groupsock/NetInterface.cpp
#endif
////////// NetInterface //////////
diff -ru live/liveMedia/MP3Internals.cpp live-patched/liveMedia/MP3Internals.cpp
--- live/liveMedia/MP3Internals.cpp Thu Nov 6 03:53:16 2003
+++ live-patched/liveMedia/MP3Internals.cpp Sun Dec 7 23:10:46 2003
@@ -27,7 +27,7 @@
// This is crufty old code that needs to be cleaned up #####
-unsigned tabsel_123[2][3][16] = {
+unsigned live_tabsel_123[2][3][16] = {
{ {32,32,64,96,128,160,192,224,256,288,320,352,384,416,448,448},
{32,32,48,56, 64, 80, 96,112,128,160,192,224,256,320,384,384},
{32,32,40,48, 56, 64, 80, 96,112,128,160,192,224,256,320,320} },
@@ -36,9 +36,9 @@
{8,8,16,24,32,40,48,56,64,80,96,112,128,144,160,160},
{8,8,16,24,32,40,48,56,64,80,96,112,128,144,160,160} }
};
-/* Note: tabsel_123[*][*][0 or 15] shouldn't occur; use dummy values there */
+/* Note: live_tabsel_123[*][*][0 or 15] shouldn't occur; use dummy values there */
-long freqs[7] = { 44100, 48000, 32000, 22050, 24000, 16000 , 11025 };
+long live_freqs[7] = { 44100, 48000, 32000, 22050, 24000, 16000 , 11025 };
static double ispow[8207];
static double aa_ca[8], aa_cs[8];
@@ -369,8 +369,8 @@
#endif
}
- bitrate = tabsel_123[isMPEG2][layer-1][bitrateIndex];
- samplingFreq = freqs[samplingFreqIndex];
+ bitrate = live_tabsel_123[isMPEG2][layer-1][bitrateIndex];
+ samplingFreq = live_freqs[samplingFreqIndex];
isStereo = (stereo > 1);
isFreeFormat = (bitrateIndex == 0);
frameSize
@@ -831,7 +831,7 @@
static unsigned MP3BitrateToBitrateIndex(unsigned bitrate /* in kbps */,
Boolean isMPEG2) {
for (unsigned i = 1; i < 15; ++i) {
- if (tabsel_123[isMPEG2][2][i] >= bitrate)
+ if (live_tabsel_123[isMPEG2][2][i] >= bitrate)
return i;
}
......@@ -86,7 +86,7 @@ LIBDVDNAV_VERSION=0.1.9
LIBDVDNAV_URL=http://ftp.snt.utwente.nl/pub/linux/gentoo/distfiles/libdvdnav-$(LIBDVDNAV_VERSION).tar.gz
LIBDVBPSI_VERSION=0.1.4
LIBDVBPSI_URL=$(VIDEOLAN)/libdvbpsi/$(LIBDVBPSI_VERSION)/libdvbpsi3-$(LIBDVBPSI_VERSION).tar.gz
LIVEDOTCOM_VERSION=2004.04.09
LIVEDOTCOM_VERSION=2004.06.02
LIVEDOTCOM_URL=$(VIDEOLAN)/testing/contrib/live.$(LIVEDOTCOM_VERSION).tar.gz
GOOM_URL=$(VIDEOLAN)/testing/contrib/goom-macosx-altivec-bin.tar.gz
LIBCACA_VERSION=0.9
......
Markdown is supported
0%
or
You are about to add 0 people to the discussion. Proceed with caution.
Finish editing this message first!
Please register or to comment